#!/bin/bash
# 9/1/2015 - Script to feed per-SSID/radio Aerohive count into Cacti. 
# ddunlap@mcnc.org
# To set up APs:
# https://community.aerohive.com/aerohive/topics/there_is_no_snmp_response_from_hiveap_121
# Example:
# ./arrayfinal.sh 192.168.24.105 hivecommunity 
# Needs bash shell - will fail if it does not exist.
# The output will show only active SSIDs/radios - shows 0 counts if there are no users.
# For example, the 5GHz radio is enabled for SSID 'aerohive' and the 2.4GHz radio for SSID 'home'.  Both radios are enabled for SSID 'Windows7'
# [root@centos60 scripts]# ./arrayfinal.sh 10.1.1.90 hivecommunity
# aerohive_wifi1:1 home_wifi1:0 Windows7_wifi0:0 Windows7_wifi1:0
# Tested on Centos 6 with Cacti 0.8.8.b
# Since your SSIDs will differ, manual creation data template and graph template is necessary but there is an example in the read-me.
export PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin

command -v bash >/dev/null 2>&1 || { echo >&2 "Bash is needed but it is not installed"; exit 1; }

# Array of radios:
myifarray=($( /usr/bin/snmpwalk -c $2 -v 2c $1 .1.3.6.1.4.1.26928.1.1.1.2.1.1.1.1 | /bin/grep -v "No Such Instance" | /bin/sed 's/.*26928.1.1.1.2.1.1.1.1\(.*\)/\1/g' | /bin/sed 's/^\(.*\) = STRING: \(.*\)/\1,\2/g' | /bin/sed 's/"//g'))

# Array of active SSIDs:
myssidarray=($( /usr/bin/snmpwalk -c $2 -v 2c $1 .1.3.6.1.4.1.26928.1.1.1.2.1.1.1.2 | /bin/grep -v "No Such Instance" | /bin/sed 's/.*26928.1.1.1.2.1.1.1.2\(.*\)/\1/g' | /bin/sed 's/^\(.*\) = STRING: \(.*\)/\1,\2/g' | /bin/sed 's/"//g'))

# Join the SSIDs with the radios then the devices/radio with the SSID/radio combinations:
/usr/bin/join -1 1 -2 1 -t, -a 2 -e 0 -o 2.1 -o 1.2 <({ /usr/bin/snmpwalk -c $2 -v 2c $1 .1.3.6.1.4.1.26928.1.1.1.2.1.2.1.13 & /usr/bin/snmpwalk -c $2 -v 2c $1 .1.3.6.1.4.1.26928.1.1.1.2.1.2.1.10 | /bin/sed 's/\(.*\)/SSID_\1/g'; } | /bin/grep -v "No Such Instance" | /bin/sed 's/.*26928.1.1.1.2.1.2.1.1[0|3]\(.*\)/\1/g' | /bin/sort | /bin/awk 'BEGIN { FS = "=" } { print $2 }' | /bin/sed 's/^ INTEGER: \(.*\)/#\1/g'  | /bin/sed 's/"//g' | /bin/sed 's/^ STRING: \(.*\)/\1/g' | /bin/grep -v "^$" | /bin/awk 'BEGIN { FS = "\n"; RS = "#" } { print $1","$2 }' | /bin/grep -v "^,$" | /bin/sort | /usr/bin/uniq -c | /bin/awk '{ print $1","$2 }' | /bin/awk 'BEGIN { FS = "," }{ if ( $2 <=11 ) { printf("%s_wifi0,%s\n", $3, $1 )} else { printf("%s_wifi1,%s\n", $3, $1 )}}' | /bin/sort | /bin/awk '{ i=1; i<=NR; i++ } { printf("%s\n", $0 ) }' | /bin/sed 's/ $//g') <(/usr/bin/join -t, -1 1 -2 1 <(printf '%s\n' "${myifarray[@]}" | sort) <(printf '%s\n' "${myssidarray[@]}" | sort) -o 1.2 -o 2.2 | /bin/grep "wifi[1|0]\."  | /bin/sed 's/\./,/g' | /bin/awk 'BEGIN { FS = "," } { print $3"_"$1","$2 }' | sort ) | /bin/awk '{ printf("%s ", $0 )}' | /bin/sed 's/,/:/g'
